pub struct EditorLanguage {
pub language: Language,
pub highlights_query: Cow<'static, str>,
}Expand description
A language definition used for syntax highlighting.
Bring your own tree-sitter grammar and its highlights query, so the editor can highlight any language without the crate depending on specific grammars.
let language = EditorLanguage::new(
tree_sitter_rust::LANGUAGE,
tree_sitter_rust::HIGHLIGHTS_QUERY,
);Fields
language: Languagehighlights_query: Cow<'static, str>Implementations